package com.shzg.project.unique.mapper;

import java.util.List;
import com.shzg.project.unique.domain.WornUniqueCodeEvent;

/**
 * 唯一码事件记录Mapper接口
 * 
 * @author shzg
 * @date 2026-03-17
 */
public interface WornUniqueCodeEventMapper 
{
    /**
     * 查询唯一码事件记录
     * 
     * @param id 唯一码事件记录主键
     * @return 唯一码事件记录
     */
    public WornUniqueCodeEvent selectWornUniqueCodeEventById(Long id);

    /**
     * 查询唯一码事件记录列表
     * 
     * @param wornUniqueCodeEvent 唯一码事件记录
     * @return 唯一码事件记录集合
     */
    public List<WornUniqueCodeEvent> selectWornUniqueCodeEventList(WornUniqueCodeEvent wornUniqueCodeEvent);

    /**
     * 新增唯一码事件记录
     * 
     * @param wornUniqueCodeEvent 唯一码事件记录
     * @return 结果
     */
    public int insertWornUniqueCodeEvent(WornUniqueCodeEvent wornUniqueCodeEvent);

    /**
     * 修改唯一码事件记录
     * 
     * @param wornUniqueCodeEvent 唯一码事件记录
     * @return 结果
     */
    public int updateWornUniqueCodeEvent(WornUniqueCodeEvent wornUniqueCodeEvent);

    /**
     * 删除唯一码事件记录
     * 
     * @param id 唯一码事件记录主键
     * @return 结果
     */
    public int deleteWornUniqueCodeEventById(Long id);

    /**
     * 批量删除唯一码事件记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWornUniqueCodeEventByIds(Long[] ids);

    /**
     * 根据唯一码id查询唯一码事件记录
     * @param id
     * @return
     */
    List<WornUniqueCodeEvent> selectByUniqueCodeId(Long id);
}
